==> qbittorrent_4.1.3.orig.tar.xz: qbittorrent-4.1.3/src/gui/speedlimitdialog.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2006  Christophe Dumez <chris@qbittorrent.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#ifndef SPEEDLIMITDIALOG_H
#define SPEEDLIMITDIALOG_H

#include <QDialog>

#include "base/bittorrent/session.h"
#include "base/utils/misc.h"

namespace Ui
{
    class SpeedLimitDialog;
}

class SpeedLimitDialog : public QDialog
{
    Q_OBJECT

public:
    explicit SpeedLimitDialog(QWidget *parent);
    ~SpeedLimitDialog();
    static long askSpeedLimit(QWidget *parent, bool *ok, QString title, long defaultVal, long maxVal=10240000);

protected slots:
    void updateSpinValue(int val) const;
    void updateSliderValue(int val) const;
    void setupDialog(long maxSlider, long val) const;

private:
    long getSpeedLimit() const;

    Ui::SpeedLimitDialog *m_ui;
};

#endif // SPEEDLIMITDIALOG_H

==> qbittorrent_4.1.7.orig.tar.xz: qbittorrent-4.1.7/src/gui/speedlimitdialog.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2006  Christophe Dumez <chris@qbittorrent.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#ifndef SPEEDLIMITDIALOG_H
#define SPEEDLIMITDIALOG_H

#include <QDialog>

namespace Ui
{
    class SpeedLimitDialog;
}

class SpeedLimitDialog : public QDialog
{
    Q_OBJECT

public:
    explicit SpeedLimitDialog(QWidget *parent);
    ~SpeedLimitDialog();
    static long askSpeedLimit(QWidget *parent, bool *ok, const QString &title, long defaultVal, long maxVal = 10240000);

private slots:
    void updateSpinValue(int val);
    void updateSliderValue(int val);

private:
    void setupDialog(long maxSlider, long val);
    int getSpeedLimit() const;

    Ui::SpeedLimitDialog *m_ui;
};

#endif // SPEEDLIMITDIALOG_H
